@@ -1,4 +1,4 @@
-jQuery(document).ready(function($){
+$(document).ready(function($){
     // need to figure out our 'base' url
     // the url looks like http://blah.../menu/blah...
     var parts = window.location.href.split('/');
@@ -19,8 +19,6 @@ jQuery(document).ready(function($){
         }
         else
            $("#lookup_box").html('');
-       $('#id_object_id').val('');
-       $('#repr_object_id').html('');
     };
 
     // this is set as a global JS variable in the template
@@ -29,7 +27,15 @@ jQuery(document).ready(function($){
         display_lookup();
     }
 
-    $("#id_content_type").change(display_lookup);
+    clear_existing = function(){
+        $('#id_object_id').val('');
+        $('#repr_object_id').html('');
+    }
+
+    $("#id_content_type").change(function(){ 
+        display_lookup(); 
+        clear_existing();
+    });
 
 });
 
