@@ -1,5 +1,5 @@
 from django.contrib.contenttypes.models import ContentType
-from django.db.models import get_model
+from django.db.models import get_model, Q
 from yama.settings import MODELS
 
 def get_content_types():
@@ -18,4 +18,6 @@ def get_queryset(request, content_type):
     q_object = MODELS[(app_label, model_name)]
     if callable(q_object):
         q_object = q_object(request)
+    if not q_object:
+        q_object = Q()
     return content_type._default_manager.filter(q_object)
